// Popis: Knihovna s uzitecnymi funkcemi
// Autor: VasaM
// Licence: CC BY 4.0 CZ



// Objekt pro pernamentni ulozeni dat
//  * modulName ... jmeno modulu (pluginu), slouzi jako prefix pro 'localStorage'
//  * varName   ... jmeno konretni promenne
//  * initial   ... Vychozi hodnota
//  * type      ... Datovy typ (string, bool, number, stringArray, numberArray)
//
// Lze pouzit nasledujici metody:
//  * set(val) ... nastavi a uloti hodnotu 'val'
//  * get()    ... ziska hodnotu
//  * update() ... pokud je hodnota modifikovana jinak nez pomocí set (napr. primy pristup k poli ziskaneho pomoci get) provede synchronizaci s trvalou pameti
//  * delete() ... odstrani promennou z pameti
var Pernament = function(modulName, varName, initial, type = 'string') {
	let name = modulName + '_' + varName;
	let data;

	function updateData() {
		data = localStorage.getItem(name);
		
		if (data == null) {
			data = initial;
			localStorage.setItem(name, initial);
		}
		else {	
			switch (type) {
				case 'string':       data = data;                                  break;
				case 'bool':         data = (data == 'true');                      break;
				case 'number':       data = Number(data);                          break;
				case 'stringArray':  data = data.split(',');                       break;   // FIXME nefunuje, pokud pole obsahuje string s ','
				case 'numberArray':  data = data.split(',').map(x => Number(x));   break;
			}
		}
	}

	updateData();
	
	
	return obj = {
		set: function(value) {
			data = value;
			localStorage.setItem(name, value);
			return value;
		},
		get: function() {
			return data;
		},
		update: function() {
			this.set(data);
			updateData();
		},
		delete: function() {
			localStorage.removeItem(name);
		}
	};
}



// Odstrani vsechny promenne daneho modulu (modulName)
function deletePernamentModul(modulName) {
	$.each(localStorage, function(key, obj) {
		if (key.startsWith(modulName + '_')) {
			localStorage.removeItem(key);
		}
	})
}


// Aktualizace poctadla zobrazenych bodu
function updatePointCount() {
	if (groupCache._latlngMarkers) {
    	document.getElementById("point_count").innerHTML=(groupCache._latlngMarkers.total);
	}
	else {
    	document.getElementById("point_count").innerHTML='0';
	}
}


// Prevod znaku na ascii kod
function code(char) {return char.charCodeAt(0);}


// Funkce na pridani prepinace
function addFilter(title, icon, id, position = -1) {
	var filter = '<div class="filter" title="' + title + '">';
	filter    += '  <img class="filtericon" src="' + icon + '">';
	filter    += '  <div class="switch" id="' + id + '"></div>';
	filter    += '</div>';

	if (position == -1) {
		$('#filter-panel').append(filter);
	}
	else {
		$('#filter-panel .filter').eq(position).before(filter);
	}		

	$('#filter-panel').width('auto');
}


// Funkce pro pridani copyrightu pro ikony ze stranek icons8.com
// Je mozne ji volat opakovane, copyright se prida jen jednou
var icons8CopyrightCalled = false;
function icons8Copyright() {
	if (!icons8CopyrightCalled) {
		icons8CopyrightCalled = true;

		addCopyright('Icons8', 'Icons by <a target="_blank" href="https://icons8.com">Icons8</a>');
	}
}


// Funkce pro pridani libovolnych dat do sekce copyrightu
function addCopyright(title, content) {
	let id = title.replace(" ", '-');

	$('#copyright div.w3-container').append('<div id="' + id + '"><h5>' + title + '</h5><p>' + content + '</p></div>');
}


// Funkce pro pridani libovolnych dat do sekce settings
function addSettings(title, content) {
	let id = title.replace(" ", '-');

	if ($('#' + id).length == 0) {
		$('#settings').append('<div id="' + id + '"><h5>' + title + '</h5><p>' + content + '</p></div>');
	}
	else {
		$('#' + id).html('<h5>' + title + '</h5><p>' + content + '</p>');
	}
}


// Odstrani duplicitni prvk z pole
function uniqueElems(inputArray) {
	return inputArray.filter(function(item, i, inputArray) {
		return i == inputArray.indexOf(item);
	});
}
